@@ -1,8 +1,7 @@
 package File::RsyBak;
-BEGIN {
-  $File::RsyBak::VERSION = '0.15';
+{
+  $File::RsyBak::VERSION = '0.16';
 }
-# ABSTRACT: Backup files/directories with histories, using rsync
 
 use 5.010;
 use strict;
@@ -23,6 +22,8 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(backup);
 
+# VERSION
+
 our %SPEC;
 
 sub _parse_path {
@@ -147,9 +148,9 @@ _
         }],
     },
 
-    cmdline_examples => [
+    examples => [
         {
-            cmd         => '/home/steven/mydata /backup/steven/mydata',
+            argv         => ['/home/steven/mydata','/backup/steven/mydata'],
             description => <<'_',
 
 Backup /home/steven/mydata to /backup/steven/mydata using the default number of
@@ -348,8 +349,11 @@ sub _rotate {
 }
 
 1;
+# ABSTRACT: Backup files/directories with histories, using rsync
 
 
+
+__END__
 =pod
 
 =head1 NAME
@@ -358,7 +362,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -515,70 +519,6 @@ TARGET/hist3.<timestamp85> comes along.
 
 None of the functions are exported by default, but they are exportable.
 
-=head2 backup(%args) -> [STATUS_CODE, ERR_MSG, RESULT]
-
-
-Backup files/directories with histories, using rsync.
-
-Returns a 3-element arrayref. STATUS_CODE is 200 on success, or an error code
-between 3xx-5xx (just like in HTTP). ERR_MSG is a string containing error
-message, RESULT is the actual result.
-
-Arguments (C<*> denotes required arguments):
-
-=over 4
-
-=item * B<source>* => I<array|str>
-
-Director(y|ies) to backup.
-
-=item * B<target>* => I<str>
-
-Backup destination.
-
-=item * B<backup> => I<bool> (default C<1>)
-
-Whether to do backup or not.
-
-If backup=1 and rotate=0 then will only create new backup without rotating
-histories.
-
-=item * B<extra_dir> => I<bool>
-
-Whether to force creation of source directory in target.
-
-If set to 1, then backup(source => '/a', target => '/backup/a') will create
-another 'a' directory in target, i.e. /backup/a/current/a. Otherwise, contents
-of a/ will be directly copied under /backup/a/current/.
-
-Will always be set to 1 if source is more than one, but default to 0 if source
-is a single directory. You can set this to 1 to so that behaviour when there is
-a single source is the same as behaviour when there are several sources.
-
-=item * B<extra_rsync_opts> => I<array>
-
-Pass extra options to rsync command.
-
-Extra options to pass to rsync command when doing backup. Note that the options
-will be shell quoted, , so you should pass it unquoted, e.g. ['--exclude',
-'/Program Files'].
-
-=item * B<histories> => I<array> (default C<[-7, 4, 3]>)
-
-Histories/history levels.
-
-Specifies number of backup histories to keep for level 1, 2, and so on. If
-number is negative, specifies number of days to keep instead (regardless of
-number of histories).
-
-=item * B<rotate> => I<bool> (default C<1>)
-
-Whether to do rotate after backup or not.
-
-If backup=0 and rotate=1 then will only do history rotating.
-
-=back
-
 =head1 HISTORY
 
 The idea for this module came out in 2006 as part of the Spanel hosting control
@@ -652,14 +592,10 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
-
